.. _plugins:

===============
Murano plug-ins
===============

Murano plug-ins help to extend the capability of murano.
There are two types of murano plug-ins which serve different purposes:

* Extend murano Core Library by implementing additional functionality.
* Add new package type classes.

This section contains the following topics:

.. toctree::
   :maxdepth: 2

   plugins/murano_plugins
   plugins/manage_plugins